summaryrefslogtreecommitdiff
path: root/src/third_party
diff options
context:
space:
mode:
authorLuke Chen <luke.chen@mongodb.com>2022-03-02 17:09:55 +1100
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2022-03-02 06:46:31 +0000
commit687b1ddd43b55834b774740e72757eaa605bb1fd (patch)
tree038e979fd21c0bb3d1d465e0f98e8abd9a2b5fad /src/third_party
parentce8245662c1d23386464ec1ba81506a86053ce0b (diff)
downloadmongo-687b1ddd43b55834b774740e72757eaa605bb1fd.tar.gz
Import wiredtiger: 7e61d33ee264007137b11de73e9e6acee913e52e from branch mongodb-master
ref: 060409ad44..7e61d33ee2 for: 6.0.0 WT-8560 Clear the obsolete on-disk time start time window if it exists
Diffstat (limited to 'src/third_party')
-rw-r--r--src/third_party/wiredtiger/import.data2
-rw-r--r--src/third_party/wiredtiger/src/include/reconcile_inline.h4
-rw-r--r--src/third_party/wiredtiger/src/include/timestamp_inline.h4
3 files changed, 7 insertions, 3 deletions
diff --git a/src/third_party/wiredtiger/import.data b/src/third_party/wiredtiger/import.data
index 6fec8a16b4a..a97ef2ce97b 100644
--- a/src/third_party/wiredtiger/import.data
+++ b/src/third_party/wiredtiger/import.data
@@ -2,5 +2,5 @@
"vendor": "wiredtiger",
"github": "wiredtiger/wiredtiger.git",
"branch": "mongodb-master",
- "commit": "060409ad4491f1629275ddf3f8fbb22c7cde35a8"
+ "commit": "7e61d33ee264007137b11de73e9e6acee913e52e"
}
diff --git a/src/third_party/wiredtiger/src/include/timestamp_inline.h b/src/third_party/wiredtiger/src/include/timestamp_inline.h
index fd27a1f8a90..f90bd97e72a 100644
--- a/src/third_party/wiredtiger/src/include/timestamp_inline.h
+++ b/src/third_party/wiredtiger/src/include/timestamp_inline.h
@@ -27,6 +27,10 @@
(tw)->start_txn == WT_TXN_NONE && (tw)->durable_stop_ts == WT_TS_NONE && \
(tw)->stop_ts == WT_TS_MAX && (tw)->stop_txn == WT_TXN_MAX && (tw)->prepare == 0)
+/* Check if the start time window is set. */
+#define WT_TIME_WINDOW_HAS_START(tw) \
+ ((tw)->start_txn != WT_TXN_NONE || (tw)->start_ts != WT_TS_NONE)
+
/* Check if the stop time window is set. */
#define WT_TIME_WINDOW_HAS_STOP(tw) ((tw)->stop_txn != WT_TXN_MAX || (tw)->stop_ts != WT_TS_MAX)
diff --git a/src/third_party/wiredtiger/src/include/reconcile_inline.h b/src/third_party/wiredtiger/src/include/reconcile_inline.h
index b3e92d8ed9e..39209bcc9af 100644
--- a/src/third_party/wiredtiger/src/include/reconcile_inline.h
+++ b/src/third_party/wiredtiger/src/include/reconcile_inline.h
@@ -490,8 +490,8 @@ __wt_rec_time_window_clear_obsolete(
session, (upd_select != NULL && vpack == NULL) || (upd_select == NULL && vpack != NULL));
tw = upd_select != NULL ? &upd_select->tw : &vpack->tw;
- /* Return if the time window is empty. */
- if (WT_TIME_WINDOW_IS_EMPTY(tw))
+ /* Return if the start time window is empty. */
+ if (!WT_TIME_WINDOW_HAS_START(tw))
return;
/*